package test;

import org.dyndns.kwitte.smartcrypt.*;

import javax.crypto.Cipher;
import java.io.*;
import java.security.NoSuchAlgorithmException;
import java.security.InvalidKeyException;
import java.security.Security;
import java.util.logging.Logger;
import static java.lang.System.err;

public class AlgorithmLoop {
    public static final String[] algorithms =
        {
            "PBEWITHSHAAND3-KEYTRIPLEDES",
            "PBEWITHSHA1AND192BITAES-CBC-BC",
            "PBEWITHSHA256AND128BITAES-CBC-BC",
            "PBEWITHHMACSHA1",
            "PBEWITHSHAAND40BITRC4",
            "PBEWITHSHAANDDES2KEY-CBC",
            "PBEWITHSHA-1AND128BITAES-CBC-BC",
            "PBEWITHSHAANDIDEA-CBC",
            "PBEWITHSHA256AND192BITAES-CBC-BC",
            "PBEWITHSHA-1AND192BITAES-CBC-BC",
            "PBEWITHSHA1AND192BITAES-CBC-BC",
            "PBEWITHSHAAND128BITAES-CBC-BC",
            "PBEWITHSHAANDTWOFISH-CBC",
            "PBEWITHSHAAND2-KEYTRIPLEDES-CBC",
            "PBEWITHHMACTIGER",
            "PBEWITHSHAANDIDEA",
            "PBEWITHSHAAND3-KEYTRIPLEDES-CBC",
            "PBEWITHSHA1AND128BITAES-CBC-BC",
            "PBEWITHSHAAND40BITRC2-CBC",
            "PBEWITHSHAAND40BITRC4",
            "PBEWITHSHA1ANDRC2-CBC",
            "PBEWITHSHA1ANDRC2",
            "PBEWITHSHA1ANDDESEDE",
            "PBEWITHSHA-256AND192BITAES-CBC-BC",
            "PBEWITHSHAAND128BITRC4",
            "PKCS12PBE",
            "PBEWITHSHAAND2-KEYTRIPLEDES-CBC",
            "PBEWITHSHA1AND40BITRC2-CBC",
            "PBEWITHSHA-1AND192BITAES-CBC-BC",
            "PBEWITHSHA1AND128BITAES-CBC-BC",
            "PBEWITHHMACSHA",
            "PBEWITHMD5AND192BITAES-CBC-OPENSSL",
            "PBEWITHSHAAND128BITRC4",
            "PBEWITHSHA1AND40BITRC4",
            "PBEWITHSHA-256AND128BITAES-CBC-BC",
            "PBEWITHSHA1AND2-KEYTRIPLEDES-CBC",
            "PBEWITHSHA-256AND128BITAES-CBC-BC",
            "PBEWITHSHA-256AND128BITAES-CBC-BC",
            "PBEWITHMD5AND192BITAES-CBC-OPENSSL",
            "PBEWITHSHA-256AND192BITAES-CBC-BC",
            "PBEWITHSHAAND40BITRC4",
            "PBEWITHSHAAND256BITAES-CBC-BC",
            "PBEWITHSHA-256AND192BITAES-CBC-BC",
            "PBEWITHMD5AND128BITAES-CBC-OPENSSL",
            "PBEWITHSHA-1AND128BITAES-CBC-BC",
            "PBEWITHSHA1AND256BITAES-CBC-BC",
            "PBEWITHSHAAND192BITAES-CBC-BC",
            "PBEWITHSHA1AND128BITAES-CBC-BC",
            "PBEWITHSHA256AND256BITAES-CBC-BC",
            "PBEWITHSHA1AND192BITAES-CBC-BC",
            "PBEWITHSHA-1AND256BITAES-CBC-BC",
            "PBEWITHSHAAND128BITRC4",
            "PBEWITHMD5AND128BITAES-CBC-OPENSSL",
            "PBEWITHMD5AND256BITAES-CBC-OPENSSL",
            "PBEWITHSHA1AND256BITAES-CBC-BC",
            "PBEWITHHMACSHA1",
            "PBEWITHMD5ANDDES",
            "PBEWithSHAAnd3KeyTripleDES",
            "PBEWITHSHAAND128BITAES-CBC-BC",
            "PBEWITHSHAANDRC4",
            "PBEWITHSHAANDRC2",
            "PBEWITHSHAAND3-KEYTRIPLEDES-CBC",
            "PBEWITHSHAAND192BITAES-CBC-BC",
            "PBEWITHMD5AND256BITAES-CBC-OPENSSL",
            "PBEWITHSHA-256AND256BITAES-CBC-BC",
            "PBEWITHMD5ANDDES",
            "PBEWITHSHAANDTWOFISH",
            "PBEWITHSHA-1AND192BITAES-CBC-BC",
            "PBEWITHSHA-1AND256BITAES-CBC-BC",
            "PBEWITHSHA256AND128BITAES-CBC-BC",
            "PBEWITHSHA256AND128BITAES-CBC-BC",
            "PBEWITHSHAAND2-KEYTRIPLEDES-CBC",
            "PBEWITHSHAAND3-KEYTRIPLEDES-CBC",
            "PBEWITHSHAAND40BITRC2-CBC",
            "PBEWITHSHA256AND192BITAES-CBC-BC",
            "PBEWITHSHA256AND192BITAES-CBC-BC",
            "PBEWITHHMACRIPEMD160",
            "PBEWithSHAAnd3KeyTripleDES",
            "PBEWITHSHAAND128BITAES-CBC-BC",
            "PBEWithSHAAnd3KeyTripleDES",
            "PBEWITHSHA-256AND256BITAES-CBC-BC",
            "PBEWITHSHA1ANDDES",
            "PBEWITHSHA-1AND128BITAES-CBC-BC",
            "PBEWITHSHA-256AND256BITAES-CBC-BC",
            "PBEWITHSHA1AND3-KEYTRIPLEDES-CBC",
            "PBEWITHSHAAND128BITRC2-CBC",
            "PBEWITHSHAAND256BITAES-CBC-BC",
            "PBEWITHSHA1ANDRC2",
            "PBEWITHHMACRIPEMD160",
            "PBEWITHSHAAND128BITRC2-CBC",
            "PBEWITHSHA1AND256BITAES-CBC-BC",
            "PBEWITHSHAAND128BITRC2-CBC",
            "PBEWITHMD5ANDRC2",
            "PBEWITHSHAAND40BITRC2-CBC",
            "PBEWITHMD5ANDRC2",
            "PBEWITHHMACSHA",
            "PBEWITHSHAANDTWOFISH-CBC",
            "PBEWITHSHAAND256BITAES-CBC-BC",
            "PBEWITHSHAAND2-KEYTRIPLEDES",
            "PBEWITHSHAANDDES3KEY-CBC",
            "PBEWITHSHAANDIDEA-CBC",
            "PBEWITHSHA1AND128BITRC2-CBC",
            "PBEWITHSHA1ANDDES",
            "PBEWITHSHA1AND128BITRC4",
            "PBEWITHSHA-1AND256BITAES-CBC-BC",
            "PBEWITHSHA256AND256BITAES-CBC-BC",
            "PBEWITHSHA256AND256BITAES-CBC-BC",
            "PBEWITHSHA1ANDRC2",
            "PBEWITHSHAAND192BITAES-CBC-BC"


        };

    public static void main(String[] args) throws IOException,
            InvalidKeyException {
        Security.addProvider(
            new org.bouncycastle.jce.provider.BouncyCastleProvider());
        for (String algorithm : algorithms) {
            String infile = "c:/tmp/testfile";
            String outfile = "c:/tmp/outfile";
            String pass = "asdfasdf";
            System.out.println(algorithm);
            long starttime = System.currentTimeMillis();
            crypt(
                    infile,
                    outfile,
                    algorithm,
                    pass
            );
            long endtime = System.currentTimeMillis();
            long totaltime = endtime - starttime;
            System.out.println("\ttime: " + totaltime);
        }
    }

    private static void crypt(String infile, String outfile, 
                       String algorithm, String password) throws IOException,
        InvalidKeyException {
                CipherFactory cf = new CipherFactoryImpl();
        FileManager fm = new FileManagerImpl();
        try {
            byte[] salt = new byte[] { 3, 4, 27, 9, 4, 9, 27, 100 };
            Cipher cipher = cf.createCipher(algorithm, password.toCharArray(), 
                                            Cipher.ENCRYPT_MODE, salt);
            OutputStream outstream = new FileOutputStream(outfile);
            InputStream instream = new FileInputStream(infile);
            fm.filterFile(new File(infile), instream, outstream,
                          cipher);
        } catch (NoSuchAlgorithmException n) {
            System.out.println("\tnot supported");
        }
    }
}
