/*
 * Smartcrypt - a tool to encrypt / decrypt files
 * Copyright (C) 2005 Kai Witte
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * For contact information see http://kwitte.dyndns.org/~kwitte/
 */
package test;

import junit.framework.*;
import org.dyndns.kwitte.smartcrypt.*;
import org.dyndns.kwitte.smartcrypt.ui.controller.EncryptAction;
import org.dyndns.kwitte.smartcrypt.ui.controller.DecryptAction;

import java.io.*;
import javax.crypto.NullCipher;
import javax.crypto.*;
import java.security.*;
import java.util.logging.*;

public class TestCryptDecrypt extends TestCase {
    private static final Logger logger =
            Logger.getLogger("org.dyndns.kwitte.smartcrypt");

    static {
        try {
            logger.setLevel(Level.SEVERE);
            Handler h = new FileHandler("error.txt");
            h.setFormatter(new SimpleFormatter());
            logger.addHandler(h);
        } catch (IOException ioe) {
            throw new AssertionError();
        }
    }

    public static void main(String[] args) {
        junit.textui.TestRunner.run(new TestSuite(TestCryptDecrypt.class));
    }

    public void testCryptDecrypt() throws IOException {
        EncryptDecrypt.main(new String[]{
            "clear.txt", "crypt.txt", "asdfasdf", "PBEWithMD5AndDES"
        },
        Cipher.ENCRYPT_MODE, new EncryptAction());
        EncryptDecrypt.main(new String[]{
            "crypt.txt", "clear02.txt", "asdfasdf", "PBEWithMD5AndDES"
        },
        Cipher.DECRYPT_MODE,
        new DecryptAction());
        filesEqual("clear.txt", "clear02.txt");
        new File("clear02.txt").delete();
        new File("crypt.txt").delete();
    }

    /**
     * Asserts that wrong passwords result in wrongly decrypted file.
     */
    public void testCryptDecrypt2() throws IOException {
        EncryptDecrypt.main(new String[]{
            "clear.txt", "crypt.txt", "asdfasdf", "PBEWithMD5AndDES"
        },
        Cipher.ENCRYPT_MODE,
        new EncryptAction());
        EncryptDecrypt.main(new String[]{
            "crypt.txt", "clear02.txt", "asdfasdg", "PBEWithMD5AndDES"
        },
        Cipher.DECRYPT_MODE,
        new DecryptAction());
        filesNotEqual("clear.txt", "clear02.txt");
        new File("clear02.txt").delete();
        new File("crypt.txt").delete();
    }

    public void testCryptDecryptTriple() throws IOException {
        EncryptDecrypt.main(new String[]{
            "clear.txt", "crypt.txt", "asdfasdf", "PBEWithMD5AndTripleDES"
        },
        Cipher.ENCRYPT_MODE,
        new EncryptAction());
        EncryptDecrypt.main(new String[]{
            "crypt.txt", "clear02.txt", "asdfasdf", "PBEWithMD5AndTripleDES"
        },
        Cipher.DECRYPT_MODE,
        new DecryptAction());
        filesEqual("clear.txt", "clear02.txt");
        new File("clear02.txt").delete();
        new File("crypt.txt").delete();
    }

    /**
     * Asserts that wrong passwords result in wrongly decrypted file.
     */
    public void testCryptDecrypt2Triple() throws IOException {
        EncryptDecrypt.main(new String[]{
            "clear.txt", "crypt.txt", "asdfasdf", "PBEWithMD5AndTripleDES"
        },
        Cipher.ENCRYPT_MODE,
        new EncryptAction());
        EncryptDecrypt.main(new String[]{
            "crypt.txt", "clear02.txt", "asdfasdg", "PBEWithMD5AndTripleDES"
        },
        Cipher.DECRYPT_MODE,
        new DecryptAction());
        filesNotEqual("clear.txt", "clear02.txt");
        new File("clear02.txt").delete();
        new File("crypt.txt").delete();
    }

    /*public void testCryptDecryptARCFOURRC4() throws IOException {
        Encrypt.main(
                new String[] {
                    "clear.txt", "crypt.txt", "asdfasdf", "DES"
                });
        Decrypt.main(
                new String[] {
                    "crypt.txt", "clear02.txt", "asdfasdf", "DES"
                });
        filesEqual("clear.txt", "clear02.txt");
        new File("clear02.txt").delete();
        new File("crypt.txt").delete();
    }*/

    private void filesEqual(String f1, String f2) throws IOException {
        InputStream in1 = new FileInputStream(f1);
        InputStream in2 = new FileInputStream(f2);
        while (in1.available() > 0) {
            assertEquals((char) in1.read(), (char) in2.read());
        }
    }

    private void filesNotEqual(String f1, String f2) throws IOException {
        InputStream in1 = new FileInputStream(f1);
        InputStream in2 = new FileInputStream(f2);
        boolean equal = true;
        while (in1.available() > 0) {
            equal &= ((char) in1.read() == (char) in2.read());
        }
        assertFalse(equal);
    }
}

