/*
 * Smartcrypt - a tool to encrypt / decrypt files
 * Copyright (C) 2005 Kai Witte
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * For contact information see http://kwitte.dyndns.org/~kwitte/
 */


package test;

import static java.lang.System.out;
import junit.framework.*;
import org.dyndns.kwitte.smartcrypt.*;
import org.dyndns.kwitte.smartcrypt.ui.controller.EncryptAction;
import org.dyndns.kwitte.smartcrypt.ui.controller.DecryptAction;

import java.io.*;
import javax.crypto.NullCipher;
import javax.crypto.*;
import java.security.*;
import java.util.logging.*;

public class TestPerformance {
    private static final Logger logger =
            Logger.getLogger("org.dyndns.kwitte.smartcrypt");
    private static final int LOOPS = 2;
    private static final String[] ALGORITHMS =
        { "PBEWithMD5AndDES", "PBEWithMD5AndTripleDES" };

    static {
        try {
            logger.setLevel(Level.SEVERE);
            Handler h = new FileHandler("error.txt");
            h.setFormatter(new SimpleFormatter());
            logger.addHandler(h);
        } catch (IOException ioe) {
            throw new AssertionError();
        }
    }

    public static void main(String[] args) throws IOException {
        new TestPerformance().testCryptDecrypt();
    }

    public void testCryptDecrypt() throws IOException {
        for (String algorithm : ALGORITHMS) {
            for (int i = 0; i < LOOPS; i++) {
                System.out.println(algorithm);
                long startTime = System.currentTimeMillis();
                EncryptDecrypt.main(
                    new String[]{
                        "clear-large.txt", "crypt.txt", "asdfasdf", algorithm
                    },
                    Cipher.ENCRYPT_MODE,
                    new EncryptAction()
                );
                long endtime = (System.currentTimeMillis() - startTime);
                out.print("encrypt: "
                                   + endtime);
                out.println(" (" 
                            + (( (double) new File("clear-large.txt").length())
                                / endtime / 1000) 
                            + " MB / s)");

                startTime = System.currentTimeMillis();
                EncryptDecrypt.main(
                    new String[] {
                        "crypt.txt", "clear02.txt", "asdfasdf", algorithm
                    },
                    Cipher.DECRYPT_MODE,
                    new DecryptAction()
                );
                endtime = (System.currentTimeMillis() - startTime);
                out.print("decrypt: "
                                   + endtime);
                out.println(" (" 
                            + (( (double) new File("clear-large.txt").length())
                                / endtime / 1000) 
                            + " MB / s)");

                new File("clear02.txt").delete();
                new File("crypt.txt").delete();
            }
        }
    }
}

